@@ -1,3 +1,8 @@
+from __future__ import annotations  # Python 3.6+ compatibility
+try:
+    from .common_utils import safe_print
+except ImportError:
+    from omnipkg.common_utils import safe_print
 import sys
 import os
 import importlib.util
